/*
 * Copyright © 2022 Soren Stoutner <soren@stoutner.com>.
 *
 * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
 *
 * Privacy Browser PC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Privacy Browser PC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MAINVIEW_H
#define MAINVIEW_H

// Qt framework headers.
#include <QPushButton>
#include <QWebEngineHistory>
#include <QWebEngineSettings>
#include <QWebEngineView>

// KDE Framework headers.
#include <KLineEdit>

class MainView : public QWidget
{
    // Include the Q_OBJECT macro.
    Q_OBJECT

public:
    // The primary contructor.
    explicit MainView(QWidget *parent);

signals:
    // Define the signals.
    void linkHovered(const QString &linkUrl) const;

public Q_SLOTS:
    // Define the public slots.
    void applyApplicationSettings() const;
    void applyDomainSettingsAndReload() const;

private Q_SLOTS:
    // Define the private slots.
    void goHome() const;
    void loadUrlFromTextBox(QString urlFromUser) const;
    void pageLinkHovered(const QString &linkUrl) const;
    void toggleJavaScript() const;
    void updateInterface() const;

private:
    // Define the private variables.
    QPushButton *backButtonPointer;
    QPushButton *forwardButtonPointer;
    QPushButton *javaScriptButtonPointer;
    KLineEdit *urlLineEditPointer;
    QWebEngineHistory *webEngineHistoryPointer;
    QWebEngineProfile *webEngineProfilePointer;
    QWebEngineSettings *webEngineSettingsPointer;
    QWebEngineView *webEngineViewPointer;

    // Define the private functions.
    void applyDomainSettings(bool reloadWebsite) const;
};
#endif
